from os import path
import eventum

##############################################################################
# These are Eventum's default settings, and may be overridden by the client. #
##############################################################################

# We enable Flask CSRF for secure forms.
CSRF_ENABLED = True

# We default to using the MONGODB 'eventum' database.
MONGODB_SETTINGS = {
    'DB': 'eventum'
}

# Path the default profile picture to use in Eventum
EVENTUM_DEFAULT_PROFILE_PICTURE = 'img/default_profile_picture.png'

# Path to the default event image
EVENTUM_DEFAULT_EVENT_IMAGE = 'img/default_event_image.jpg'

# Whether or not Google Auth should be enabled or not.  If it is not enabled,
# you will default to a super-user account that bypasses all Google auth.
EVENTUM_GOOGLE_AUTH_ENABLED = True

# The name of the application log
EVENTUM_APP_LOG_NAME = 'app.log'

# The name of the Werkzeug log
EVENTUM_WERKZEUG_LOG_NAME = 'werkzeug.log'

# The maximum size of the Eventum logs
EVENTUM_LOG_FILE_MAX_SIZE = 256

# The URL at which the Eventum admin interface should be mounted.
EVENTUM_URL_PREFIX = '/admin'

# File extensions that are allowed to be uploaded via the Media tab.
EVENTUM_ALLOWED_UPLOAD_EXTENSIONS = set(['.png', '.jpg', '.jpeg', '.gif'])

# The Eventum base path. If you're not sure what this is, don't mess with it.
EVENTUM_BASEDIR = eventum.__path__[0]

# Eventum static folder
EVENTUM_STATIC_FOLDER = path.join(EVENTUM_BASEDIR, 'static/')

# Eventum  SCSS folder
EVENTUM_SCSS_FOLDER = path.join(EVENTUM_STATIC_FOLDER, 'eventum_scss/')

# Eventum templates folder
EVENTUM_TEMPLATE_FOLDER = path.join(EVENTUM_BASEDIR, 'templates/')

######################
# Must be overridden #
######################

# Path from the root of your project to the installed application client
# secret JSON file downloaded from Google.
EVENTUM_INSTALLED_APP_CLIENT_SECRET_PATH = None

# Path from the root of your project to the installed application credentials
# JSON file generated by the authorization in the previous step.
EVENTUM_INSTALLED_APP_CREDENTIALS_PATH = None

# Path from the root of your project to the client secret JSON file
EVENTUM_CLIENT_SECRETS_PATH = None

# The [Google Calendar ID][gcal-id] for the private calendar to which
# unpublished events should be synced.
EVENTUM_PRIVATE_CALENDAR_ID = None

# The [Google Calendar ID][gcal-id] for the public calendar to which published
# events should be synced.
EVENTUM_PUBLIC_CALENDAR_ID = None

# Path from the root of your project to the folder where uploaded images
# should be stored.
EVENTUM_UPLOAD_FOLDER = None

# Path from the root of your project to the folder where uploaded images that
# are then deleted should be stored.
EVENTUM_DELETE_FOLDER = None

# Will be set elsewhere, do not set directly
EVENTUM_GOOGLE_CLIENT_ID = None
